

SLARecord
======================

.. currentmodule:: pyvo.dal.sla

.. autoclass:: SLARecord
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~SLARecord.final_level
      ~SLARecord.initial_level
      ~SLARecord.species_name
      ~SLARecord.status
      ~SLARecord.title
      ~SLARecord.wavelength

   
   

   
   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: final_level
   .. autoattribute:: initial_level
   .. autoattribute:: species_name
   .. autoattribute:: status
   .. autoattribute:: title
   .. autoattribute:: wavelength

   
   

   
   
   